@@ -2,6 +2,7 @@ package org.gcube.portlets.user.td.expressionwidget.client;
 
 import java.util.ArrayList;
 
+import org.gcube.portlets.user.td.expressionwidget.client.expression.ConditionWidget;
 import org.gcube.portlets.user.td.expressionwidget.client.properties.ColumnDataPropertiesCombo;
 import org.gcube.portlets.user.td.expressionwidget.client.properties.ColumnDataTypeProperties;
 import org.gcube.portlets.user.td.expressionwidget.client.resources.ExpressionResources;
@@ -12,6 +13,7 @@ import org.gcube.portlets.user.td.expressionwidget.shared.model.logical.C_Not;
 import org.gcube.portlets.user.td.expressionwidget.shared.rule.RuleDescriptionData;
 import org.gcube.portlets.user.td.expressionwidget.shared.rule.RuleScopeType;
 import org.gcube.portlets.user.td.expressionwidget.shared.rule.type.TDBaseColumnRuleType;
+import org.gcube.portlets.user.td.expressionwidget.shared.rule.type.TDRuleColumnType;
 import org.gcube.portlets.user.td.monitorwidget.client.utils.UtilsGXT3;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.ExpressionWrapperEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.expression.C_ExpressionContainer;
@@ -87,6 +89,8 @@ public class ColumnExpressionPanel extends FramedPanel {
 	private ComboBox<ColumnData> comboCols;
 	private RuleDialog parentRuleDialog;
 
+	private RuleDescriptionData initialRuleDescriptionData;
+
 	private TextField ruleName;
 	private TextField ruleDescription;
 
@@ -205,6 +209,22 @@ public class ColumnExpressionPanel extends FramedPanel {
 		createOnRule();
 	}
 
+	public ColumnExpressionPanel(RuleDialog parentRuleDialog,
+			RuleDescriptionData ruleDescriptionData, EventBus eventBus) {
+		super();
+		setWidth(WIDTH);
+		setHeight(HEIGHT);
+		type = ColumnExpressionPanelType.Rule;
+		this.parentRuleDialog = parentRuleDialog;
+		this.initialRuleDescriptionData = ruleDescriptionData;
+		this.column = null;
+		this.columns = null;
+		this.eventBus = eventBus;
+		Log.debug("Column:" + column);
+
+		createOnRule();
+	}
+
 	protected void createOnRule() {
 		forceLayoutOnResize = true;
 
@@ -274,7 +294,7 @@ public class ColumnExpressionPanel extends FramedPanel {
 		basicLayout.add(flowButton, new VerticalLayoutData(1, 36, new Margins(
 				5, 2, 5, 2)));
 		add(basicLayout);
-		
+
 		conditionWidget.disable();
 
 	}
@@ -283,10 +303,17 @@ public class ColumnExpressionPanel extends FramedPanel {
 	private void createColumnMockUp(VerticalLayoutContainer propertiesLayout) {
 		ruleName = new TextField();
 		ruleName.setToolTip("Rule Name");
+		if (initialRuleDescriptionData != null) {
+			ruleName.setValue(initialRuleDescriptionData.getName());
+		}
 		FieldLabel ruleNameLabel = new FieldLabel(ruleName, "Rule Name");
 
 		ruleDescription = new TextField();
 		ruleDescription.setToolTip("Rule Description");
+		if (initialRuleDescriptionData != null) {
+			ruleDescription.setValue(initialRuleDescriptionData
+					.getDescription());
+		}
 		FieldLabel ruleDescriptionLabel = new FieldLabel(ruleDescription,
 				"Rule Description");
 
@@ -349,6 +376,18 @@ public class ColumnExpressionPanel extends FramedPanel {
 		comboAttributeType.setTypeAhead(true);
 		comboAttributeType.setTriggerAction(TriggerAction.ALL);
 
+		if (initialRuleDescriptionData != null) {
+			ColumnDataType cdt = retrieveColumnDataType();
+			if (cdt != null) {
+				ColumnDataTypeElement cdte = ColumnDataTypeStore
+						.selectedAttributeElement(cdt);
+				if (cdte != null) {
+					comboAttributeType.setValue(cdte);
+
+				}
+			}
+		}
+
 		comboAttributeTypeLabel = new FieldLabel(comboAttributeType,
 				"Data Type");
 
@@ -370,6 +409,18 @@ public class ColumnExpressionPanel extends FramedPanel {
 
 	}
 
+	private ColumnDataType retrieveColumnDataType() {
+		TDRuleColumnType tdRuleColumnType = initialRuleDescriptionData
+				.getTdRuleColumnType();
+		if (tdRuleColumnType instanceof TDBaseColumnRuleType) {
+			TDBaseColumnRuleType tdBaseColumnRuleType = (TDBaseColumnRuleType) tdRuleColumnType;
+			return tdBaseColumnRuleType.getColumnDataType();
+		}
+
+		return null;
+
+	}
+
 	/*
 	 * protected void addHandlersForComboColumnTypeCode( final
 	 * LabelProvider<ColumnTypeCodeElement> labelProvider) { comboColumnTypeCode
@@ -611,7 +662,7 @@ public class ColumnExpressionPanel extends FramedPanel {
 						columnMockUp.getColumnDataType());
 
 				RuleDescriptionData ruleDescriptionData = new RuleDescriptionData(
-						0, ruleNameS, ruleDescriptionS, RuleScopeType.COLUMN,
+						0, ruleNameS, ruleDescriptionS, null, RuleScopeType.COLUMN,
 						tdBaseColumnRule, exp);
 				return ruleDescriptionData;
 			} else {
@@ -1082,7 +1133,7 @@ public class ColumnExpressionPanel extends FramedPanel {
 			eventBus.fireEvent(expressionEvent);
 			break;
 		case Rule:
-			if(!conditionWidget.isEnabled()){
+			if (!conditionWidget.isEnabled()) {
 				UtilsGXT3.alert("Attention", "Fill all field!");
 				return;
 			}
